# Copyright 1999-2024 Gentoo Authors
# Distributed under the terms of the GNU General Public License v2

EAPI=8

USE_RUBY="ruby31 ruby32 ruby33"

RUBY_FAKEGEM_EXTRADOC="CHANGELOG.md README.md"
RUBY_FAKEGEM_GEMSPEC="oxidized.gemspec"

inherit ruby-fakegem systemd

DESCRIPTION="Network device configuration backup tool."
HOMEPAGE="https://github.com/ytti/oxidized"
SRC_URI="https://github.com/ytti/oxidized/archive/refs/tags/${PV}.tar.gz -> ${P}.tar.gz"

LICENSE="Apache-2.0"
SLOT="0"
KEYWORDS="amd64"

RDEPEND="
	${RDEPEND}
	acct-group/${PN}
	acct-user/${PN}
"

ruby_add_rdepend "
	>=dev-ruby/asetus-0.1
	>=dev-ruby/bcrypt_pbkdf-1.1.0
	>=dev-ruby/ed25519-1.3.0
	>=dev-ruby/net-ftp-0.2
	>=dev-ruby/net-http-digest_auth-1.4
	>=dev-ruby/net-scp-4.0
	>=dev-ruby/net-ssh-7.3
	>=dev-ruby/net-telnet-0.2
	>=dev-ruby/psych-5.0
	>=dev-ruby/rugged-1.6
	>=dev-ruby/slop-4.6
"

all_ruby_install() {
	all_fakegem_install

	insinto /etc/${PN}
	doins "${FILESDIR}/config"
	doins "${FILESDIR}/router.db"

	keepdir /var/lib/${PN}/backups/configs
	keepdir /var/lib/${PN}/git-repos
	keepdir /var/log/${PN}/crashes

	fowners -R oxidized:oxidized \
		/etc/${PN} \
		/var/lib/${PN} \
		/var/log/${PN}

	# logrotate
	insinto /etc/logrotate.d
	newins extra/oxidized.logrotate oxidized

	# systemd unit
	systemd_dounit "${FILESDIR}/oxidized.service"
}
